# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .prod import (
    ProdResource,
    AsyncProdResource,
    ProdResourceWithRawResponse,
    AsyncProdResourceWithRawResponse,
    ProdResourceWithStreamingResponse,
    AsyncProdResourceWithStreamingResponse,
)
from .tags import (
    TagsResource,
    AsyncTagsResource,
    TagsResourceWithRawResponse,
    AsyncTagsResourceWithRawResponse,
    TagsResourceWithStreamingResponse,
    AsyncTagsResourceWithStreamingResponse,
)
from .fields import (
    FieldsResource,
    AsyncFieldsResource,
    FieldsResourceWithRawResponse,
    AsyncFieldsResourceWithRawResponse,
    FieldsResourceWithStreamingResponse,
    AsyncFieldsResourceWithStreamingResponse,
)
from .outlines import (
    OutlinesResource,
    AsyncOutlinesResource,
    OutlinesResourceWithRawResponse,
    AsyncOutlinesResourceWithRawResponse,
    OutlinesResourceWithStreamingResponse,
    AsyncOutlinesResourceWithStreamingResponse,
)
from .profiles import (
    ProfilesResource,
    AsyncProfilesResource,
    ProfilesResourceWithRawResponse,
    AsyncProfilesResourceWithRawResponse,
    ProfilesResourceWithStreamingResponse,
    AsyncProfilesResourceWithStreamingResponse,
)
from .snapshots import (
    SnapshotsResource,
    AsyncSnapshotsResource,
    SnapshotsResourceWithRawResponse,
    AsyncSnapshotsResourceWithRawResponse,
    SnapshotsResourceWithStreamingResponse,
    AsyncSnapshotsResourceWithStreamingResponse,
)
from .templates import (
    TemplatesResource,
    AsyncTemplatesResource,
    TemplatesResourceWithRawResponse,
    AsyncTemplatesResourceWithRawResponse,
    TemplatesResourceWithStreamingResponse,
    AsyncTemplatesResourceWithStreamingResponse,
)
from .reports_v3 import (
    ReportsV3Resource,
    AsyncReportsV3Resource,
    ReportsV3ResourceWithRawResponse,
    AsyncReportsV3ResourceWithRawResponse,
    ReportsV3ResourceWithStreamingResponse,
    AsyncReportsV3ResourceWithStreamingResponse,
)
from .collections import (
    CollectionsResource,
    AsyncCollectionsResource,
    CollectionsResourceWithRawResponse,
    AsyncCollectionsResourceWithRawResponse,
    CollectionsResourceWithStreamingResponse,
    AsyncCollectionsResourceWithStreamingResponse,
)
from .created_fields import (
    CreatedFieldsResource,
    AsyncCreatedFieldsResource,
    CreatedFieldsResourceWithRawResponse,
    AsyncCreatedFieldsResourceWithRawResponse,
    CreatedFieldsResourceWithStreamingResponse,
    AsyncCreatedFieldsResourceWithStreamingResponse,
)
from .prompt_templates import (
    PromptTemplatesResource,
    AsyncPromptTemplatesResource,
    PromptTemplatesResourceWithRawResponse,
    AsyncPromptTemplatesResourceWithRawResponse,
    PromptTemplatesResourceWithStreamingResponse,
    AsyncPromptTemplatesResourceWithStreamingResponse,
)

__all__ = [
    "ProdResource",
    "AsyncProdResource",
    "ProdResourceWithRawResponse",
    "AsyncProdResourceWithRawResponse",
    "ProdResourceWithStreamingResponse",
    "AsyncProdResourceWithStreamingResponse",
    "CollectionsResource",
    "AsyncCollectionsResource",
    "CollectionsResourceWithRawResponse",
    "AsyncCollectionsResourceWithRawResponse",
    "CollectionsResourceWithStreamingResponse",
    "AsyncCollectionsResourceWithStreamingResponse",
    "CreatedFieldsResource",
    "AsyncCreatedFieldsResource",
    "CreatedFieldsResourceWithRawResponse",
    "AsyncCreatedFieldsResourceWithRawResponse",
    "CreatedFieldsResourceWithStreamingResponse",
    "AsyncCreatedFieldsResourceWithStreamingResponse",
    "FieldsResource",
    "AsyncFieldsResource",
    "FieldsResourceWithRawResponse",
    "AsyncFieldsResourceWithRawResponse",
    "FieldsResourceWithStreamingResponse",
    "AsyncFieldsResourceWithStreamingResponse",
    "OutlinesResource",
    "AsyncOutlinesResource",
    "OutlinesResourceWithRawResponse",
    "AsyncOutlinesResourceWithRawResponse",
    "OutlinesResourceWithStreamingResponse",
    "AsyncOutlinesResourceWithStreamingResponse",
    "ProfilesResource",
    "AsyncProfilesResource",
    "ProfilesResourceWithRawResponse",
    "AsyncProfilesResourceWithRawResponse",
    "ProfilesResourceWithStreamingResponse",
    "AsyncProfilesResourceWithStreamingResponse",
    "PromptTemplatesResource",
    "AsyncPromptTemplatesResource",
    "PromptTemplatesResourceWithRawResponse",
    "AsyncPromptTemplatesResourceWithRawResponse",
    "PromptTemplatesResourceWithStreamingResponse",
    "AsyncPromptTemplatesResourceWithStreamingResponse",
    "ReportsV3Resource",
    "AsyncReportsV3Resource",
    "ReportsV3ResourceWithRawResponse",
    "AsyncReportsV3ResourceWithRawResponse",
    "ReportsV3ResourceWithStreamingResponse",
    "AsyncReportsV3ResourceWithStreamingResponse",
    "SnapshotsResource",
    "AsyncSnapshotsResource",
    "SnapshotsResourceWithRawResponse",
    "AsyncSnapshotsResourceWithRawResponse",
    "SnapshotsResourceWithStreamingResponse",
    "AsyncSnapshotsResourceWithStreamingResponse",
    "TagsResource",
    "AsyncTagsResource",
    "TagsResourceWithRawResponse",
    "AsyncTagsResourceWithRawResponse",
    "TagsResourceWithStreamingResponse",
    "AsyncTagsResourceWithStreamingResponse",
    "TemplatesResource",
    "AsyncTemplatesResource",
    "TemplatesResourceWithRawResponse",
    "AsyncTemplatesResourceWithRawResponse",
    "TemplatesResourceWithStreamingResponse",
    "AsyncTemplatesResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Iterable, Optional
from typing_extensions import TypedDict

from .field_param import FieldParam

__all__ = ["TemplateUpdateParams"]


class TemplateUpdateParams(TypedDict, total=False):
    description: Optional[str]

    fields: Iterable[FieldParam]

    name: str

    questions: List[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Iterable, Optional
from typing_extensions import Required, TypedDict

from .field_param import FieldParam

__all__ = ["TemplateCreateParams"]


class TemplateCreateParams(TypedDict, total=False):
    fields: Required[Iterable[FieldParam]]

    name: Required[str]

    description: Optional[str]

    questions: List[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional
from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["FieldUpdateParams"]


class FieldUpdateParams(TypedDict, total=False):
    path_id: Required[Annotated[int, PropertyInfo(alias="id")]]

    body_id: Annotated[int, PropertyInfo(alias="id")]

    description: str

    enum_many: bool

    enum_values: List[str]

    name: str

    rel_template: Optional[int]

    rel_template_id: Optional[int]

    type: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .blank import (
    BlankResource,
    AsyncBlankResource,
    BlankResourceWithRawResponse,
    AsyncBlankResourceWithRawResponse,
    BlankResourceWithStreamingResponse,
    AsyncBlankResourceWithStreamingResponse,
)
from .profile import (
    ProfileResource,
    AsyncProfileResource,
    ProfileResourceWithRawResponse,
    AsyncProfileResourceWithRawResponse,
    ProfileResourceWithStreamingResponse,
    AsyncProfileResourceWithStreamingResponse,
)
from .template import (
    TemplateResource,
    AsyncTemplateResource,
    TemplateResourceWithRawResponse,
    AsyncTemplateResourceWithRawResponse,
    TemplateResourceWithStreamingResponse,
    AsyncTemplateResourceWithStreamingResponse,
)

__all__ = [
    "ProfileResource",
    "AsyncProfileResource",
    "ProfileResourceWithRawResponse",
    "AsyncProfileResourceWithRawResponse",
    "ProfileResourceWithStreamingResponse",
    "AsyncProfileResourceWithStreamingResponse",
    "TemplateResource",
    "AsyncTemplateResource",
    "TemplateResourceWithRawResponse",
    "AsyncTemplateResourceWithRawResponse",
    "TemplateResourceWithStreamingResponse",
    "AsyncTemplateResourceWithStreamingResponse",
    "BlankResource",
    "AsyncBlankResource",
    "BlankResourceWithRawResponse",
    "AsyncBlankResourceWithRawResponse",
    "BlankResourceWithStreamingResponse",
    "AsyncBlankResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .created_field import CreatedField

__all__ = ["CreatedFieldListResponse"]

CreatedFieldListResponse: TypeAlias = List[CreatedField]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .bulk_created_field import BulkCreatedField as BulkCreatedField
from .bulk_profiles_to_collection import BulkProfilesToCollection as BulkProfilesToCollection
from .created_field_create_params import CreatedFieldCreateParams as CreatedFieldCreateParams
from .created_field_list_response import CreatedFieldListResponse as CreatedFieldListResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .tag import Tag as Tag
from .field import Field as Field
from .shared import Report as Report, Profile as Profile, Snapshot as Snapshot
from .outline import Outline as Outline
from .template import Template as Template
from .tag_param import TagParam as TagParam
from .collection import Collection as Collection
from .field_param import FieldParam as FieldParam
from .tag_profile import TagProfile as TagProfile
from .created_field import CreatedField as CreatedField
from .template_param import TemplateParam as TemplateParam
from .field_to_template import FieldToTemplate as FieldToTemplate
from .tag_create_params import TagCreateParams as TagCreateParams
from .tag_list_response import TagListResponse as TagListResponse
from .tag_update_params import TagUpdateParams as TagUpdateParams
from .prod_schema_params import ProdSchemaParams as ProdSchemaParams
from .profile_tag_params import ProfileTagParams as ProfileTagParams
from .field_create_params import FieldCreateParams as FieldCreateParams
from .field_list_response import FieldListResponse as FieldListResponse
from .field_update_params import FieldUpdateParams as FieldUpdateParams
from .prod_schema_response import ProdSchemaResponse as ProdSchemaResponse
from .field_template_params import FieldTemplateParams as FieldTemplateParams
from .outline_create_params import OutlineCreateParams as OutlineCreateParams
from .outline_list_response import OutlineListResponse as OutlineListResponse
from .outline_update_params import OutlineUpdateParams as OutlineUpdateParams
from .profile_create_params import ProfileCreateParams as ProfileCreateParams
from .profile_list_response import ProfileListResponse as ProfileListResponse
from .profile_update_params import ProfileUpdateParams as ProfileUpdateParams
from .snapshot_list_response import SnapshotListResponse as SnapshotListResponse
from .template_create_params import TemplateCreateParams as TemplateCreateParams
from .template_list_response import TemplateListResponse as TemplateListResponse
from .template_update_params import TemplateUpdateParams as TemplateUpdateParams
from .collection_create_params import CollectionCreateParams as CollectionCreateParams
from .collection_list_response import CollectionListResponse as CollectionListResponse
from .collection_update_params import CollectionUpdateParams as CollectionUpdateParams
from .reports_v3_create_params import ReportsV3CreateParams as ReportsV3CreateParams
from .reports_v3_list_response import ReportsV3ListResponse as ReportsV3ListResponse
from .reports_v3_update_params import ReportsV3UpdateParams as ReportsV3UpdateParams
from .created_field_create_params import CreatedFieldCreateParams as CreatedFieldCreateParams
from .created_field_list_response import CreatedFieldListResponse as CreatedFieldListResponse
from .created_field_update_params import CreatedFieldUpdateParams as CreatedFieldUpdateParams
from .prompt_template_save_params import PromptTemplateSaveParams as PromptTemplateSaveParams
from .created_field_profile_params import CreatedFieldProfileParams as CreatedFieldProfileParams
from .prompt_template_create_params import PromptTemplateCreateParams as PromptTemplateCreateParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import TypedDict

from .tag_param import TagParam

__all__ = ["ProfileUpdateParams"]


class ProfileUpdateParams(TypedDict, total=False):
    specification: str

    tags: Iterable[TagParam]

    template_id: int



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .create_profile_snapshot import CreateProfileSnapshot

__all__ = ["SnapshotListResponse"]

SnapshotListResponse: TypeAlias = List[CreateProfileSnapshot]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional

import httpx

from ..types import outline_create_params, outline_update_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.outline import Outline
from ..types.outline_list_response import OutlineListResponse

__all__ = ["OutlinesResource", "AsyncOutlinesResource"]


class OutlinesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> OutlinesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/evrimai/python-client#accessing-raw-response-data-eg-headers
        """
        return OutlinesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> OutlinesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/evrimai/python-client#with_streaming_response
        """
        return OutlinesResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        perspective: str,
        profile_id: int,
        report_title: str,
        section_titles: List[str],
        outline: Optional[object] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Outline:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/prod/v0/outlines/",
            body=maybe_transform(
                {
                    "perspective": perspective,
                    "profile_id": profile_id,
                    "report_title": report_title,
                    "section_titles": section_titles,
                    "outline": outline,
                },
                outline_create_params.OutlineCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Outline,
        )

    def retrieve(
        self,
        id: int,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Outline:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            f"/prod/v0/outlines/{id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Outline,
        )

    def update(
        self,
        id: int,
        *,
        outline: Optional[object] | NotGiven = NOT_GIVEN,
        perspective: str | NotGiven = NOT_GIVEN,
        profile_id: int | NotGiven = NOT_GIVEN,
        report_title: str | NotGiven = NOT_GIVEN,
        section_titles: List[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Outline:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._patch(
            f"/prod/v0/outlines/{id}/",
            body=maybe_transform(
                {
                    "outline": outline,
                    "perspective": perspective,
                    "profile_id": profile_id,
                    "report_title": report_title,
                    "section_titles": section_titles,
                },
                outline_update_params.OutlineUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Outline,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> OutlineListResponse:
        return self._get(
            "/prod/v0/outlines/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OutlineListResponse,
        )

    def delete(
        self,
        id: int,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/prod/v0/outlines/{id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncOutlinesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncOutlinesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/evrimai/python-client#accessing-raw-response-data-eg-headers
        """
        return AsyncOutlinesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncOutlinesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/evrimai/python-client#with_streaming_response
        """
        return AsyncOutlinesResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        perspective: str,
        profile_id: int,
        report_title: str,
        section_titles: List[str],
        outline: Optional[object] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Outline:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/prod/v0/outlines/",
            body=await async_maybe_transform(
                {
                    "perspective": perspective,
                    "profile_id": profile_id,
                    "report_title": report_title,
                    "section_titles": section_titles,
                    "outline": outline,
                },
                outline_create_params.OutlineCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Outline,
        )

    async def retrieve(
        self,
        id: int,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Outline:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            f"/prod/v0/outlines/{id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Outline,
        )

    async def update(
        self,
        id: int,
        *,
        outline: Optional[object] | NotGiven = NOT_GIVEN,
        perspective: str | NotGiven = NOT_GIVEN,
        profile_id: int | NotGiven = NOT_GIVEN,
        report_title: str | NotGiven = NOT_GIVEN,
        section_titles: List[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Outline:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._patch(
            f"/prod/v0/outlines/{id}/",
            body=await async_maybe_transform(
                {
                    "outline": outline,
                    "perspective": perspective,
                    "profile_id": profile_id,
                    "report_title": report_title,
                    "section_titles": section_titles,
                },
                outline_update_params.OutlineUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Outline,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> OutlineListResponse:
        return await self._get(
            "/prod/v0/outlines/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OutlineListResponse,
        )

    async def delete(
        self,
        id: int,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/prod/v0/outlines/{id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class OutlinesResourceWithRawResponse:
    def __init__(self, outlines: OutlinesResource) -> None:
        self._outlines = outlines

        self.create = to_raw_response_wrapper(
            outlines.create,
        )
        self.retrieve = to_raw_response_wrapper(
            outlines.retrieve,
        )
        self.update = to_raw_response_wrapper(
            outlines.update,
        )
        self.list = to_raw_response_wrapper(
            outlines.list,
        )
        self.delete = to_raw_response_wrapper(
            outlines.delete,
        )


class AsyncOutlinesResourceWithRawResponse:
    def __init__(self, outlines: AsyncOutlinesResource) -> None:
        self._outlines = outlines

        self.create = async_to_raw_response_wrapper(
            outlines.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            outlines.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            outlines.update,
        )
        self.list = async_to_raw_response_wrapper(
            outlines.list,
        )
        self.delete = async_to_raw_response_wrapper(
            outlines.delete,
        )


class OutlinesResourceWithStreamingResponse:
    def __init__(self, outlines: OutlinesResource) -> None:
        self._outlines = outlines

        self.create = to_streamed_response_wrapper(
            outlines.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            outlines.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            outlines.update,
        )
        self.list = to_streamed_response_wrapper(
            outlines.list,
        )
        self.delete = to_streamed_response_wrapper(
            outlines.delete,
        )


class AsyncOutlinesResourceWithStreamingResponse:
    def __init__(self, outlines: AsyncOutlinesResource) -> None:
        self._outlines = outlines

        self.create = async_to_streamed_response_wrapper(
            outlines.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            outlines.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            outlines.update,
        )
        self.list = async_to_streamed_response_wrapper(
            outlines.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            outlines.delete,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Required, TypedDict

from .tag_param import TagParam

__all__ = ["ProfileCreateParams"]


class ProfileCreateParams(TypedDict, total=False):
    specification: Required[str]

    template_id: Required[int]

    tags: Iterable[TagParam]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.


from ..outline import Outline
from ..._models import BaseModel

__all__ = ["Report"]


class Report(BaseModel):
    id: int

    outline: Outline

    report: object



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .profile import (
    ProfileResource,
    AsyncProfileResource,
    ProfileResourceWithRawResponse,
    AsyncProfileResourceWithRawResponse,
    ProfileResourceWithStreamingResponse,
    AsyncProfileResourceWithStreamingResponse,
)
from .template import (
    TemplateResource,
    AsyncTemplateResource,
    TemplateResourceWithRawResponse,
    AsyncTemplateResourceWithRawResponse,
    TemplateResourceWithStreamingResponse,
    AsyncTemplateResourceWithStreamingResponse,
)
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["BlankResource", "AsyncBlankResource"]


class BlankResource(SyncAPIResource):
    @cached_property
    def profile(self) -> ProfileResource:
        return ProfileResource(self._client)

    @cached_property
    def template(self) -> TemplateResource:
        return TemplateResource(self._client)

    @cached_property
    def with_raw_response(self) -> BlankResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/evrimai/python-client#accessing-raw-response-data-eg-headers
        """
        return BlankResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> BlankResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/evrimai/python-client#with_streaming_response
        """
        return BlankResourceWithStreamingResponse(self)


class AsyncBlankResource(AsyncAPIResource):
    @cached_property
    def profile(self) -> AsyncProfileResource:
        return AsyncProfileResource(self._client)

    @cached_property
    def template(self) -> AsyncTemplateResource:
        return AsyncTemplateResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncBlankResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/evrimai/python-client#accessing-raw-response-data-eg-headers
        """
        return AsyncBlankResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncBlankResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/evrimai/python-client#with_streaming_response
        """
        return AsyncBlankResourceWithStreamingResponse(self)


class BlankResourceWithRawResponse:
    def __init__(self, blank: BlankResource) -> None:
        self._blank = blank

    @cached_property
    def profile(self) -> ProfileResourceWithRawResponse:
        return ProfileResourceWithRawResponse(self._blank.profile)

    @cached_property
    def template(self) -> TemplateResourceWithRawResponse:
        return TemplateResourceWithRawResponse(self._blank.template)


class AsyncBlankResourceWithRawResponse:
    def __init__(self, blank: AsyncBlankResource) -> None:
        self._blank = blank

    @cached_property
    def profile(self) -> AsyncProfileResourceWithRawResponse:
        return AsyncProfileResourceWithRawResponse(self._blank.profile)

    @cached_property
    def template(self) -> AsyncTemplateResourceWithRawResponse:
        return AsyncTemplateResourceWithRawResponse(self._blank.template)


class BlankResourceWithStreamingResponse:
    def __init__(self, blank: BlankResource) -> None:
        self._blank = blank

    @cached_property
    def profile(self) -> ProfileResourceWithStreamingResponse:
        return ProfileResourceWithStreamingResponse(self._blank.profile)

    @cached_property
    def template(self) -> TemplateResourceWithStreamingResponse:
        return TemplateResourceWithStreamingResponse(self._blank.template)


class AsyncBlankResourceWithStreamingResponse:
    def __init__(self, blank: AsyncBlankResource) -> None:
        self._blank = blank

    @cached_property
    def profile(self) -> AsyncProfileResourceWithStreamingResponse:
        return AsyncProfileResourceWithStreamingResponse(self._blank.profile)

    @cached_property
    def template(self) -> AsyncTemplateResourceWithStreamingResponse:
        return AsyncTemplateResourceWithStreamingResponse(self._blank.template)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional

import httpx

from ..types import field_create_params, field_update_params, field_template_params
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..types.field import Field
from .._base_client import make_request_options
from ..types.field_to_template import FieldToTemplate
from ..types.field_list_response import FieldListResponse

__all__ = ["FieldsResource", "AsyncFieldsResource"]


class FieldsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> FieldsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/evrimai/python-client#accessing-raw-response-data-eg-headers
        """
        return FieldsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> FieldsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/evrimai/python-client#with_streaming_response
        """
        return FieldsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        description: str,
        name: str,
        type: str,
        id: int | NotGiven = NOT_GIVEN,
        enum_many: bool | NotGiven = NOT_GIVEN,
        enum_values: List[str] | NotGiven = NOT_GIVEN,
        rel_template: Optional[int] | NotGiven = NOT_GIVEN,
        rel_template_id: Optional[int] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Field:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/prod/v0/fields/",
            body=maybe_transform(
                {
                    "description": description,
                    "name": name,
                    "type": type,
                    "id": id,
                    "enum_many": enum_many,
                    "enum_values": enum_values,
                    "rel_template": rel_template,
                    "rel_template_id": rel_template_id,
                },
                field_create_params.FieldCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Field,
        )

    def retrieve(
        self,
        id: int,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Field:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            f"/prod/v0/fields/{id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Field,
        )

    def update(
        self,
        *,
        path_id: int,
        body_id: int | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        enum_many: bool | NotGiven = NOT_GIVEN,
        enum_values: List[str] | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        rel_template: Optional[int] | NotGiven = NOT_GIVEN,
        rel_template_id: Optional[int] | NotGiven = NOT_GIVEN,
        type: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Field:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._patch(
            f"/prod/v0/fields/{path_id}/",
            body=maybe_transform(
                {
                    "body_id": body_id,
                    "description": description,
                    "enum_many": enum_many,
                    "enum_values": enum_values,
                    "name": name,
                    "rel_template": rel_template,
                    "rel_template_id": rel_template_id,
                    "type": type,
                },
                field_update_params.FieldUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Field,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> FieldListResponse:
        return self._get(
            "/prod/v0/fields/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=FieldListResponse,
        )

    def delete(
        self,
        id: int,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/prod/v0/fields/{id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def template(
        self,
        field_id: str,
        *,
        template_id: int,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> FieldToTemplate:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not field_id:
            raise ValueError(f"Expected a non-empty value for `field_id` but received {field_id!r}")
        return self._post(
            f"/prod/v0/fields/{field_id}/template/",
            body=maybe_transform({"template_id": template_id}, field_template_params.FieldTemplateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=FieldToTemplate,
        )


class AsyncFieldsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncFieldsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/evrimai/python-client#accessing-raw-response-data-eg-headers
        """
        return AsyncFieldsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncFieldsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/evrimai/python-client#with_streaming_response
        """
        return AsyncFieldsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        description: str,
        name: str,
        type: str,
        id: int | NotGiven = NOT_GIVEN,
        enum_many: bool | NotGiven = NOT_GIVEN,
        enum_values: List[str] | NotGiven = NOT_GIVEN,
        rel_template: Optional[int] | NotGiven = NOT_GIVEN,
        rel_template_id: Optional[int] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Field:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/prod/v0/fields/",
            body=await async_maybe_transform(
                {
                    "description": description,
                    "name": name,
                    "type": type,
                    "id": id,
                    "enum_many": enum_many,
                    "enum_values": enum_values,
                    "rel_template": rel_template,
                    "rel_template_id": rel_template_id,
                },
                field_create_params.FieldCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Field,
        )

    async def retrieve(
        self,
        id: int,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Field:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            f"/prod/v0/fields/{id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Field,
        )

    async def update(
        self,
        *,
        path_id: int,
        body_id: int | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        enum_many: bool | NotGiven = NOT_GIVEN,
        enum_values: List[str] | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        rel_template: Optional[int] | NotGiven = NOT_GIVEN,
        rel_template_id: Optional[int] | NotGiven = NOT_GIVEN,
        type: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Field:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._patch(
            f"/prod/v0/fields/{path_id}/",
            body=await async_maybe_transform(
                {
                    "body_id": body_id,
                    "description": description,
                    "enum_many": enum_many,
                    "enum_values": enum_values,
                    "name": name,
                    "rel_template": rel_template,
                    "rel_template_id": rel_template_id,
                    "type": type,
                },
                field_update_params.FieldUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Field,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> FieldListResponse:
        return await self._get(
            "/prod/v0/fields/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=FieldListResponse,
        )

    async def delete(
        self,
        id: int,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/prod/v0/fields/{id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def template(
        self,
        field_id: str,
        *,
        template_id: int,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> FieldToTemplate:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not field_id:
            raise ValueError(f"Expected a non-empty value for `field_id` but received {field_id!r}")
        return await self._post(
            f"/prod/v0/fields/{field_id}/template/",
            body=await async_maybe_transform({"template_id": template_id}, field_template_params.FieldTemplateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=FieldToTemplate,
        )


class FieldsResourceWithRawResponse:
    def __init__(self, fields: FieldsResource) -> None:
        self._fields = fields

        self.create = to_raw_response_wrapper(
            fields.create,
        )
        self.retrieve = to_raw_response_wrapper(
            fields.retrieve,
        )
        self.update = to_raw_response_wrapper(
            fields.update,
        )
        self.list = to_raw_response_wrapper(
            fields.list,
        )
        self.delete = to_raw_response_wrapper(
            fields.delete,
        )
        self.template = to_raw_response_wrapper(
            fields.template,
        )


class AsyncFieldsResourceWithRawResponse:
    def __init__(self, fields: AsyncFieldsResource) -> None:
        self._fields = fields

        self.create = async_to_raw_response_wrapper(
            fields.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            fields.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            fields.update,
        )
        self.list = async_to_raw_response_wrapper(
            fields.list,
        )
        self.delete = async_to_raw_response_wrapper(
            fields.delete,
        )
        self.template = async_to_raw_response_wrapper(
            fields.template,
        )


class FieldsResourceWithStreamingResponse:
    def __init__(self, fields: FieldsResource) -> None:
        self._fields = fields

        self.create = to_streamed_response_wrapper(
            fields.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            fields.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            fields.update,
        )
        self.list = to_streamed_response_wrapper(
            fields.list,
        )
        self.delete = to_streamed_response_wrapper(
            fields.delete,
        )
        self.template = to_streamed_response_wrapper(
            fields.template,
        )


class AsyncFieldsResourceWithStreamingResponse:
    def __init__(self, fields: AsyncFieldsResource) -> None:
        self._fields = fields

        self.create = async_to_streamed_response_wrapper(
            fields.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            fields.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            fields.update,
        )
        self.list = async_to_streamed_response_wrapper(
            fields.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            fields.delete,
        )
        self.template = async_to_streamed_response_wrapper(
            fields.template,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from evrim import Evrim, AsyncEvrim
from evrim.types import (
    Field,
    FieldToTemplate,
    FieldListResponse,
)
from tests.utils import assert_matches_type

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestFields:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: Evrim) -> None:
        field = client.fields.create(
            description="description",
            name="name",
            type="xxx",
        )
        assert_matches_type(Field, field, path=["response"])

    @parametrize
    def test_method_create_with_all_params(self, client: Evrim) -> None:
        field = client.fields.create(
            description="description",
            name="name",
            type="xxx",
            id=0,
            enum_many=True,
            enum_values=["string"],
            rel_template=0,
            rel_template_id=0,
        )
        assert_matches_type(Field, field, path=["response"])

    @parametrize
    def test_raw_response_create(self, client: Evrim) -> None:
        response = client.fields.with_raw_response.create(
            description="description",
            name="name",
            type="xxx",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        field = response.parse()
        assert_matches_type(Field, field, path=["response"])

    @parametrize
    def test_streaming_response_create(self, client: Evrim) -> None:
        with client.fields.with_streaming_response.create(
            description="description",
            name="name",
            type="xxx",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            field = response.parse()
            assert_matches_type(Field, field, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_retrieve(self, client: Evrim) -> None:
        field = client.fields.retrieve(
            0,
        )
        assert_matches_type(Field, field, path=["response"])

    @parametrize
    def test_raw_response_retrieve(self, client: Evrim) -> None:
        response = client.fields.with_raw_response.retrieve(
            0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        field = response.parse()
        assert_matches_type(Field, field, path=["response"])

    @parametrize
    def test_streaming_response_retrieve(self, client: Evrim) -> None:
        with client.fields.with_streaming_response.retrieve(
            0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            field = response.parse()
            assert_matches_type(Field, field, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_update(self, client: Evrim) -> None:
        field = client.fields.update(
            path_id=0,
        )
        assert_matches_type(Field, field, path=["response"])

    @parametrize
    def test_method_update_with_all_params(self, client: Evrim) -> None:
        field = client.fields.update(
            path_id=0,
            body_id=0,
            description="description",
            enum_many=True,
            enum_values=["string"],
            name="name",
            rel_template=0,
            rel_template_id=0,
            type="xxx",
        )
        assert_matches_type(Field, field, path=["response"])

    @parametrize
    def test_raw_response_update(self, client: Evrim) -> None:
        response = client.fields.with_raw_response.update(
            path_id=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        field = response.parse()
        assert_matches_type(Field, field, path=["response"])

    @parametrize
    def test_streaming_response_update(self, client: Evrim) -> None:
        with client.fields.with_streaming_response.update(
            path_id=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            field = response.parse()
            assert_matches_type(Field, field, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_list(self, client: Evrim) -> None:
        field = client.fields.list()
        assert_matches_type(FieldListResponse, field, path=["response"])

    @parametrize
    def test_raw_response_list(self, client: Evrim) -> None:
        response = client.fields.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        field = response.parse()
        assert_matches_type(FieldListResponse, field, path=["response"])

    @parametrize
    def test_streaming_response_list(self, client: Evrim) -> None:
        with client.fields.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            field = response.parse()
            assert_matches_type(FieldListResponse, field, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_delete(self, client: Evrim) -> None:
        field = client.fields.delete(
            0,
        )
        assert field is None

    @parametrize
    def test_raw_response_delete(self, client: Evrim) -> None:
        response = client.fields.with_raw_response.delete(
            0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        field = response.parse()
        assert field is None

    @parametrize
    def test_streaming_response_delete(self, client: Evrim) -> None:
        with client.fields.with_streaming_response.delete(
            0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            field = response.parse()
            assert field is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_template(self, client: Evrim) -> None:
        field = client.fields.template(
            field_id="field_id",
            template_id=0,
        )
        assert_matches_type(FieldToTemplate, field, path=["response"])

    @parametrize
    def test_raw_response_template(self, client: Evrim) -> None:
        response = client.fields.with_raw_response.template(
            field_id="field_id",
            template_id=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        field = response.parse()
        assert_matches_type(FieldToTemplate, field, path=["response"])

    @parametrize
    def test_streaming_response_template(self, client: Evrim) -> None:
        with client.fields.with_streaming_response.template(
            field_id="field_id",
            template_id=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            field = response.parse()
            assert_matches_type(FieldToTemplate, field, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_template(self, client: Evrim) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `field_id` but received ''"):
            client.fields.with_raw_response.template(
                field_id="",
                template_id=0,
            )


class TestAsyncFields:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_create(self, async_client: AsyncEvrim) -> None:
        field = await async_client.fields.create(
            description="description",
            name="name",
            type="xxx",
        )
        assert_matches_type(Field, field, path=["response"])

    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncEvrim) -> None:
        field = await async_client.fields.create(
            description="description",
            name="name",
            type="xxx",
            id=0,
            enum_many=True,
            enum_values=["string"],
            rel_template=0,
            rel_template_id=0,
        )
        assert_matches_type(Field, field, path=["response"])

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncEvrim) -> None:
        response = await async_client.fields.with_raw_response.create(
            description="description",
            name="name",
            type="xxx",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        field = await response.parse()
        assert_matches_type(Field, field, path=["response"])

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncEvrim) -> None:
        async with async_client.fields.with_streaming_response.create(
            description="description",
            name="name",
            type="xxx",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            field = await response.parse()
            assert_matches_type(Field, field, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncEvrim) -> None:
        field = await async_client.fields.retrieve(
            0,
        )
        assert_matches_type(Field, field, path=["response"])

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncEvrim) -> None:
        response = await async_client.fields.with_raw_response.retrieve(
            0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        field = await response.parse()
        assert_matches_type(Field, field, path=["response"])

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncEvrim) -> None:
        async with async_client.fields.with_streaming_response.retrieve(
            0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            field = await response.parse()
            assert_matches_type(Field, field, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_update(self, async_client: AsyncEvrim) -> None:
        field = await async_client.fields.update(
            path_id=0,
        )
        assert_matches_type(Field, field, path=["response"])

    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncEvrim) -> None:
        field = await async_client.fields.update(
            path_id=0,
            body_id=0,
            description="description",
            enum_many=True,
            enum_values=["string"],
            name="name",
            rel_template=0,
            rel_template_id=0,
            type="xxx",
        )
        assert_matches_type(Field, field, path=["response"])

    @parametrize
    async def test_raw_response_update(self, async_client: AsyncEvrim) -> None:
        response = await async_client.fields.with_raw_response.update(
            path_id=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        field = await response.parse()
        assert_matches_type(Field, field, path=["response"])

    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncEvrim) -> None:
        async with async_client.fields.with_streaming_response.update(
            path_id=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            field = await response.parse()
            assert_matches_type(Field, field, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_list(self, async_client: AsyncEvrim) -> None:
        field = await async_client.fields.list()
        assert_matches_type(FieldListResponse, field, path=["response"])

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncEvrim) -> None:
        response = await async_client.fields.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        field = await response.parse()
        assert_matches_type(FieldListResponse, field, path=["response"])

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncEvrim) -> None:
        async with async_client.fields.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            field = await response.parse()
            assert_matches_type(FieldListResponse, field, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_delete(self, async_client: AsyncEvrim) -> None:
        field = await async_client.fields.delete(
            0,
        )
        assert field is None

    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncEvrim) -> None:
        response = await async_client.fields.with_raw_response.delete(
            0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        field = await response.parse()
        assert field is None

    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncEvrim) -> None:
        async with async_client.fields.with_streaming_response.delete(
            0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            field = await response.parse()
            assert field is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_template(self, async_client: AsyncEvrim) -> None:
        field = await async_client.fields.template(
            field_id="field_id",
            template_id=0,
        )
        assert_matches_type(FieldToTemplate, field, path=["response"])

    @parametrize
    async def test_raw_response_template(self, async_client: AsyncEvrim) -> None:
        response = await async_client.fields.with_raw_response.template(
            field_id="field_id",
            template_id=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        field = await response.parse()
        assert_matches_type(FieldToTemplate, field, path=["response"])

    @parametrize
    async def test_streaming_response_template(self, async_client: AsyncEvrim) -> None:
        async with async_client.fields.with_streaming_response.template(
            field_id="field_id",
            template_id=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            field = await response.parse()
            assert_matches_type(FieldToTemplate, field, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_template(self, async_client: AsyncEvrim) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `field_id` but received ''"):
            await async_client.fields.with_raw_response.template(
                field_id="",
                template_id=0,
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional

import httpx

from ...types import tag_create_params, tag_update_params
from ..._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from ..._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .profiles import (
    ProfilesResource,
    AsyncProfilesResource,
    ProfilesResourceWithRawResponse,
    AsyncProfilesResourceWithRawResponse,
    ProfilesResourceWithStreamingResponse,
    AsyncProfilesResourceWithStreamingResponse,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...types.tag import Tag
from .collections import (
    CollectionsResource,
    AsyncCollectionsResource,
    CollectionsResourceWithRawResponse,
    AsyncCollectionsResourceWithRawResponse,
    CollectionsResourceWithStreamingResponse,
    AsyncCollectionsResourceWithStreamingResponse,
)
from ..._base_client import make_request_options
from ...types.tag_list_response import TagListResponse

__all__ = ["TagsResource", "AsyncTagsResource"]


class TagsResource(SyncAPIResource):
    @cached_property
    def collections(self) -> CollectionsResource:
        return CollectionsResource(self._client)

    @cached_property
    def profiles(self) -> ProfilesResource:
        return ProfilesResource(self._client)

    @cached_property
    def with_raw_response(self) -> TagsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/evrimai/python-client#accessing-raw-response-data-eg-headers
        """
        return TagsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TagsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/evrimai/python-client#with_streaming_response
        """
        return TagsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        name: str,
        description: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Tag:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/prod/v0/tags/",
            body=maybe_transform(
                {
                    "name": name,
                    "description": description,
                },
                tag_create_params.TagCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Tag,
        )

    def retrieve(
        self,
        id: int,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Tag:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            f"/prod/v0/tags/{id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Tag,
        )

    def update(
        self,
        id: int,
        *,
        description: Optional[str] | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Tag:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._patch(
            f"/prod/v0/tags/{id}/",
            body=maybe_transform(
                {
                    "description": description,
                    "name": name,
                },
                tag_update_params.TagUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Tag,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TagListResponse:
        return self._get(
            "/prod/v0/tags/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TagListResponse,
        )

    def delete(
        self,
        id: int,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/prod/v0/tags/{id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncTagsResource(AsyncAPIResource):
    @cached_property
    def collections(self) -> AsyncCollectionsResource:
        return AsyncCollectionsResource(self._client)

    @cached_property
    def profiles(self) -> AsyncProfilesResource:
        return AsyncProfilesResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncTagsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/evrimai/python-client#accessing-raw-response-data-eg-headers
        """
        return AsyncTagsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTagsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/evrimai/python-client#with_streaming_response
        """
        return AsyncTagsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        name: str,
        description: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Tag:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/prod/v0/tags/",
            body=await async_maybe_transform(
                {
                    "name": name,
                    "description": description,
                },
                tag_create_params.TagCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Tag,
        )

    async def retrieve(
        self,
        id: int,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Tag:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            f"/prod/v0/tags/{id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Tag,
        )

    async def update(
        self,
        id: int,
        *,
        description: Optional[str] | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Tag:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._patch(
            f"/prod/v0/tags/{id}/",
            body=await async_maybe_transform(
                {
                    "description": description,
                    "name": name,
                },
                tag_update_params.TagUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Tag,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TagListResponse:
        return await self._get(
            "/prod/v0/tags/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TagListResponse,
        )

    async def delete(
        self,
        id: int,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/prod/v0/tags/{id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class TagsResourceWithRawResponse:
    def __init__(self, tags: TagsResource) -> None:
        self._tags = tags

        self.create = to_raw_response_wrapper(
            tags.create,
        )
        self.retrieve = to_raw_response_wrapper(
            tags.retrieve,
        )
        self.update = to_raw_response_wrapper(
            tags.update,
        )
        self.list = to_raw_response_wrapper(
            tags.list,
        )
        self.delete = to_raw_response_wrapper(
            tags.delete,
        )

    @cached_property
    def collections(self) -> CollectionsResourceWithRawResponse:
        return CollectionsResourceWithRawResponse(self._tags.collections)

    @cached_property
    def profiles(self) -> ProfilesResourceWithRawResponse:
        return ProfilesResourceWithRawResponse(self._tags.profiles)


class AsyncTagsResourceWithRawResponse:
    def __init__(self, tags: AsyncTagsResource) -> None:
        self._tags = tags

        self.create = async_to_raw_response_wrapper(
            tags.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            tags.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            tags.update,
        )
        self.list = async_to_raw_response_wrapper(
            tags.list,
        )
        self.delete = async_to_raw_response_wrapper(
            tags.delete,
        )

    @cached_property
    def collections(self) -> AsyncCollectionsResourceWithRawResponse:
        return AsyncCollectionsResourceWithRawResponse(self._tags.collections)

    @cached_property
    def profiles(self) -> AsyncProfilesResourceWithRawResponse:
        return AsyncProfilesResourceWithRawResponse(self._tags.profiles)


class TagsResourceWithStreamingResponse:
    def __init__(self, tags: TagsResource) -> None:
        self._tags = tags

        self.create = to_streamed_response_wrapper(
            tags.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            tags.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            tags.update,
        )
        self.list = to_streamed_response_wrapper(
            tags.list,
        )
        self.delete = to_streamed_response_wrapper(
            tags.delete,
        )

    @cached_property
    def collections(self) -> CollectionsResourceWithStreamingResponse:
        return CollectionsResourceWithStreamingResponse(self._tags.collections)

    @cached_property
    def profiles(self) -> ProfilesResourceWithStreamingResponse:
        return ProfilesResourceWithStreamingResponse(self._tags.profiles)


class AsyncTagsResourceWithStreamingResponse:
    def __init__(self, tags: AsyncTagsResource) -> None:
        self._tags = tags

        self.create = async_to_streamed_response_wrapper(
            tags.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            tags.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            tags.update,
        )
        self.list = async_to_streamed_response_wrapper(
            tags.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            tags.delete,
        )

    @cached_property
    def collections(self) -> AsyncCollectionsResourceWithStreamingResponse:
        return AsyncCollectionsResourceWithStreamingResponse(self._tags.collections)

    @cached_property
    def profiles(self) -> AsyncProfilesResourceWithStreamingResponse:
        return AsyncProfilesResourceWithStreamingResponse(self._tags.profiles)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .bulk_job import BulkJob as BulkJob
from .profile_create_params import ProfileCreateParams as ProfileCreateParams
from .profile_list_response import ProfileListResponse as ProfileListResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .bulk import (
    BulkResource,
    AsyncBulkResource,
    BulkResourceWithRawResponse,
    AsyncBulkResourceWithRawResponse,
    BulkResourceWithStreamingResponse,
    AsyncBulkResourceWithStreamingResponse,
)
from .prod import (
    ProdResource,
    AsyncProdResource,
    ProdResourceWithRawResponse,
    AsyncProdResourceWithRawResponse,
    ProdResourceWithStreamingResponse,
    AsyncProdResourceWithStreamingResponse,
)
from .blank import (
    BlankResource,
    AsyncBlankResource,
    BlankResourceWithRawResponse,
    AsyncBlankResourceWithRawResponse,
    BlankResourceWithStreamingResponse,
    AsyncBlankResourceWithStreamingResponse,
)

__all__ = [
    "BlankResource",
    "AsyncBlankResource",
    "BlankResourceWithRawResponse",
    "AsyncBlankResourceWithRawResponse",
    "BlankResourceWithStreamingResponse",
    "AsyncBlankResourceWithStreamingResponse",
    "BulkResource",
    "AsyncBulkResource",
    "BulkResourceWithRawResponse",
    "AsyncBulkResourceWithRawResponse",
    "BulkResourceWithStreamingResponse",
    "AsyncBulkResourceWithStreamingResponse",
    "ProdResource",
    "AsyncProdResource",
    "ProdResourceWithRawResponse",
    "AsyncProdResourceWithRawResponse",
    "ProdResourceWithStreamingResponse",
    "AsyncProdResourceWithStreamingResponse",
]
